###########################################################################
#
# win32 makefile -- src/w32server
# A component of the Greenstone digital library software
# from the New Zealand Digital Library Project at the
# University of Waikato, New Zealand.
#
# Copyright (C) 1999  The New Zealand Digital Library Project
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
###########################################################################

GSDL_DIR = ..\..
INDEXERS_DIR = $(GSDL_DIR)\indexers
COLSERVR_DIR = $(GSDL_DIR)\src\colservr
PROTOCOL_DIR = $(GSDL_DIR)\src\protocol
RECPT_DIR = $(GSDL_DIR)\src\recpt


GSDL_VC4 = 0
STLPATH = "$(GSDL_DIR)\packages\windows\stlport\stlport"
ENABLE_ACCENTFOLD = 1


!IF $(GSDL_VC4)
CPPFLAGS = -GX
!ELSE
CPPFLAGS = -EHsc
!ENDIF

!IF $(ENABLE_ACCENTFOLD)
ACCENTFOLD_LIBS = "$(GSDL_DIR)\indexers\packages\unac\libunac.lib" "$(GSDL_DIR)\indexers\packages\unac\iconv.lib"
!ELSE
ACCENTFOLD_LIBS = 
!ENDIF


AR = lib
CC = cl
DEFS = -D__WIN32__ -DHAVE_CONFIG_H -D_LITTLE_ENDIAN -DPARADOCNUM \
       -DSHORT_SUFFIX -D_CRT_SECURE_NO_DEPRECATE
INCLUDES = -I"$(GSDL_DIR)" -I"$(GSDL_DIR)\lib" -I"$(COLSERVR_DIR)" -I"$(PROTOCOL_DIR)" -I"$(RECPT_DIR)" \
	   -I"$(GSDL_DIR)\src\colservr" -I"$(GSDL_DIR)\indexers\mg" \
	   -I"$(GSDL_DIR)\packages\windows\gdbm\gdbm" \
           -I"$(GSDL_DIR)\indexers\mg\lib" -I"$(GSDL_DIR)\indexers\mg\src\text" \
    	   -I"$(GSDL_DIR)\indexers\mgpp\lib" -I"$(GSDL_DIR)\indexers\mgpp\text"
LDFLAGS =
LIBS = "$(GSDL_DIR)\packages\windows\crypt\crypt\crypt.lib" "$(GSDL_DIR)\packages\windows\expat\expat\libexpat.lib" \
        "$(GSDL_DIR)\packages\windows\gdbm\gdbm\gdbm.lib" $(ACCENTFOLD_LIBS) $(Z3950_LIBS)
RSC = rc
WINLIBS = kernel32.lib user32.lib gdi32.lib winspool.lib \
          comdlg32.lib advapi32.lib shell32.lib ole32.lib \
          oleaut32.lib uuid.lib odbc32.lib odbccp32.lib 
#wsock32.lib


!IF $(GSDL_VC4)
DEFS = $(DEFS) -DGSDL_NAMESPACE_BROKEN -DGSDL_USE_IOS_H -D__STL_NO_NEW_IOSTREAMS
INCLUDES = $(INCLUDES) -I$(STLPATH)
!ENDIF


COMPILE = $(CC) -nologo -c $(CPPFLAGS) $(DEFS) $(INCLUDES)
LINK = $(CC) -nologo $(LDFLAGS) -Fe"$@"


.SUFFIXES:
.SUFFIXES: .cpp .obj
.cpp.obj:
	$(COMPILE) $< 


SOURCES = \
	cgiwrapper.cpp \
	conftools.cpp \
	d_winsock.cpp \
	fnord.cpp \
	httpreq.cpp \
	httpsend.cpp \
        httpsrv.cpp \
	locate.cpp \
	netio.cpp \
	parse.cpp \
	settings.cpp \
	startbrowser.cpp \
	wincgiutils.cpp

OBJECTS = \
	cgiwrapper.obj \
	conftools.obj \
	d_winsock.obj \
	fnord.obj \
	httpreq.obj \
	httpsend.obj \
        httpsrv.obj \
	locate.obj \
	netio.obj \
	parse.obj \
	settings.obj \
	startbrowser.obj \
	wincgiutils.obj

GSDL_LIBS = \
	"$(RECPT_DIR)\gsdlrecpt.lib" \
	"$(PROTOCOL_DIR)\gsdlprotocol.lib" \
	"$(COLSERVR_DIR)\gsdlcolservr.lib" \
	"$(GSDL_DIR)\lib\gsdllib.lib" \
	"$(INDEXERS_DIR)\mg\src\text\libmgtext.lib" \
	"$(INDEXERS_DIR)\mg\lib\libmglib.lib" \
	"$(INDEXERS_DIR)\mgpp\text\libmgpptext.lib" \
	"$(INDEXERS_DIR)\mgpp\lib\libmgpplib.lib"

EXECUTABLE_OBJECTS = \
	$(OBJECTS) \
	$(GSDL_LIBS)

EXECUTABLE = server.exe


server.exe: $(EXECUTABLE_OBJECTS)
	$(LINK) $(EXECUTABLE_OBJECTS) $(LIBS) $(WINLIBS) 

all: $(EXECUTABLE)

install:
	copy $(EXECUTABLE) "$(GSDL_DIR)"

clean:
	del *.obj
	del $(EXECUTABLE)


SOURCE = "$(GSDL_DIR)\src\w32server\newgsdl.bmp"
SOURCE = "$(GSDL_DIR)\src\w32server\resource.h"
SOURCE = "$(GSDL_DIR)\src\w32server\server.ico"
SOURCE = "$(GSDL_DIR)\src\w32server\gsdlcol.bmp"
SOURCE = "$(GSDL_DIR)\src\w32server\server.rc"
DEP_RSC_SERVE=\
	"$(GSDL_DIR)\src\w32server\gsdlcol.bmp"\
	"$(GSDL_DIR)\src\w32server\newgsdl.bmp"\
	"$(GSDL_DIR)\src\w32server\server.ico"

server.res : $(SOURCE) $(DEP_RSC_SERVE) "$(GSDL_DIR)\src\w32server"
   $(RSC) /l 0x409 /fo"$(GSDL_DIR)\src\w32server\server.res" /i "$(GSDL_DIR)\src\w32server" \
 /d "NDEBUG" $(SOURCE)


"$(GSDL_DIR)\src\w32server\server.res" : $(SOURCE) $(DEP_RSC_SERVE) "$(GSDL_DIR)\src\w32server"
   $(RSC) /l 0x409 /fo"$(GSDL_DIR)\src\w32server\server.res" /i "$(GSDL_DIR)\src\w32server" \
 /d "NDEBUG" $(SOURCE)

